"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.YfmFileSpecs = exports.fileType = exports.yfmFileNodeName = void 0;
const file_extension_1 = require("@diplodoc/file-extension");
const schema_1 = require("../../../../utils/schema");
const const_1 = require("./const");
var const_2 = require("./const");
Object.defineProperty(exports, "yfmFileNodeName", { enumerable: true, get: function () { return const_2.yfmFileNodeName; } });
exports.fileType = (0, schema_1.nodeTypeFactory)(const_1.yfmFileNodeName);
const YfmFileSpecs = (builder) => {
    builder.configureMd((md) => md.use((0, file_extension_1.transform)({ bundle: false })));
    builder.addNode(const_1.yfmFileNodeName, () => ({
        spec: {
            group: 'inline',
            inline: true,
            attrs: const_1.fileNodeAttrsSpec,
            parseDOM: [
                {
                    tag: `a[class="${file_extension_1.FileClassName.Link}"]`,
                    getAttrs(p) {
                        const elem = p;
                        const attrs = {};
                        for (const name of const_1.KNOWN_ATTRS) {
                            const value = elem.getAttribute(name);
                            if (value) {
                                attrs[name] = value;
                            }
                        }
                        return attrs;
                    },
                    priority: 101,
                },
            ],
            toDOM(node) {
                const a = document.createElement('a');
                a.contentEditable = 'false';
                a.classList.add(file_extension_1.FileClassName.Link);
                for (const [key, value] of Object.entries(node.attrs)) {
                    if (value)
                        a.setAttribute(key, value);
                }
                const span = document.createElement('span');
                span.classList.add(file_extension_1.FileClassName.Icon);
                a.appendChild(span);
                a.append(node.attrs[file_extension_1.FileHtmlAttr.Download]);
                return a;
            },
        },
        fromMd: {
            tokenName: const_1.yfmFileNodeName,
            tokenSpec: {
                name: const_1.yfmFileNodeName,
                type: 'node',
                getAttrs: (tok) => {
                    var _a;
                    return Object.fromEntries((_a = tok.attrs) !== null && _a !== void 0 ? _a : []);
                },
            },
        },
        toMd: (state, node) => {
            const attrsStr = Object.entries(node.attrs)
                .reduce((arr, [key, value]) => {
                if (value) {
                    if (key in const_1.LINK_TO_FILE_ATTRS_MAP) {
                        key = const_1.LINK_TO_FILE_ATTRS_MAP[key];
                    }
                    arr.push(`${key}="${value.replace(/"/g, '')}"`);
                }
                return arr;
            }, [])
                .join(' ');
            state.write(`${file_extension_1.FILE_MARKUP_PREFIX}${attrsStr} %}`);
        },
    }));
};
exports.YfmFileSpecs = YfmFileSpecs;
